@@ -195,6 +195,7 @@ pub use qttypes::*;
 pub use tablemodel::*;
 
 pub mod connections;
+pub mod qtcore;
 pub mod future;
 pub mod itemmodel;
 pub mod listmodel;
@@ -207,15 +208,19 @@ pub mod qtquickcontrols2;
 pub mod scenegraph;
 pub mod tablemodel;
 #[cfg(feature = "webengine")]
+#[cfg(not(any(qt_6_0, qt_6_1)))]
+#[cfg(not(all(target_os = "windows", not(target_env = "msvc"))))]
 pub mod webengine;
 
 /// Module intended for glob import.
 pub mod prelude {
+    #[cfg(qt_5_8)]
+    pub use crate::qtdeclarative::qml_register_enum;
     pub use crate::{
         qml_register_type, qrc, qt_base_class, qt_method, qt_plugin, qt_property, qt_signal,
-        QAbstractListModel, QByteArray, QColor, QDate, QDateTime, QModelIndex, QObject, QObjectBox,
-        QPointer, QQmlExtensionPlugin, QQuickItem, QQuickView, QRectF, QString, QTime, QVariant,
-        QmlEngine,
+        QAbstractListModel, QByteArray, QColor, QDate, QDateTime, QEnum, QModelIndex, QObject,
+        QObjectBox, QPointer, QQmlExtensionPlugin, QQuickItem, QQuickView, QRectF, QString, QTime,
+        QVariant, QmlEngine,
     };
 }
 
@@ -257,9 +262,13 @@ impl QObjectCppWrapper {
     }
 }
 
+// TODO: Remove before 1.0
+#[doc(hidden)]
+#[deprecated] pub type QObjectDescription = QObjectDescriptor;
+
 #[doc(hidden)]
 #[repr(C)]
-pub struct QObjectDescription {
+pub struct QObjectDescriptor {
     pub size: usize,
     pub meta_object: *const QMetaObject,
     pub create: unsafe extern "C" fn(
@@ -324,14 +333,14 @@ pub trait QObject {
     // Part of the trait structure that sub trait must have.
     // Copy/paste this code replacing QObject with the type.
 
-    /// Returns a QObjectDescription for this type
-    fn get_object_description() -> &'static QObjectDescription
+    /// Returns a QObjectDescriptor for this type
+    fn get_object_description() -> &'static QObjectDescriptor
     where
         Self: Sized,
     {
         unsafe {
-            &*cpp!([]-> *const QObjectDescription as "RustObjectDescription const *" {
-                return rustObjectDescription<RustObject<QObject>>();
+            &*cpp!([]-> *const QObjectDescriptor as "RustQObjectDescriptor const*" {
+                return RustQObjectDescriptor::instance<RustObject<QObject>>();
             })
         }
     }
@@ -346,9 +355,9 @@ impl dyn QObject {
     /// QVariant is unsafe as it does not manage life time
     pub unsafe fn as_qvariant(&self) -> QVariant {
         let self_ = self.get_cpp_object();
-        cpp! {[self_ as "QObject*"] -> QVariant as "QVariant"  {
+        cpp!([self_ as "QObject*"] -> QVariant as "QVariant"  {
             return QVariant::fromValue(self_);
-        }}
+        })
     }
 
     /// See Qt documentation for QObject::destroyed
@@ -513,8 +522,8 @@ impl<'pin, T: QObject + ?Sized + 'pin> QObjectPinned<'pin, T> {
 }
 
 impl<'pin, T: QObject + ?Sized + 'pin> QObjectPinned<'pin, T> {
-    /// Internal function used from the code generated by the QObject derive macro
-    /// unsafe because one must ensure it does not move in memory
+    /// Internal function used from the code generated by the QObject derive macro.
+    /// Unsafe because one must ensure it does not move in memory.
     pub unsafe fn new(inner: &'pin RefCell<T>) -> Self {
         QObjectPinned(inner)
     }
@@ -953,6 +962,7 @@ pub const USER_ROLE: i32 = 0x0100;
 /// # Input
 ///
 /// The macro accepts the following formal grammar in pseudo [rust macro syntax][macro-doc]:
+///
 /// ```txt
 /// macro call ::= qrc!( $f:Function $( $r:Recource ),* )
 /// Function   ::= $v:vis $name:ident
@@ -979,7 +989,7 @@ pub const USER_ROLE: i32 = 0x0100;
 ///  - `$base_dir:physical`: optional path to base directory on local file
 ///    system, separated from the prefix by the `as` keyword.
 ///    By default, base directory is the cargo project's root - directory with
-///    Cargo.toml, a.k.a. [`$CARGO_MANIFEST_DIR`][].
+///    _Cargo.toml_, a.k.a. [`$CARGO_MANIFEST_DIR`][].
 ///    (Custom extention which does not interfere with qrc format,
 ///    but merely resolves physical path of files in this resource relative
 ///    to the base directory, and helps keeping both project's root directory
@@ -1013,6 +1023,7 @@ pub const USER_ROLE: i32 = 0x0100;
 /// # Example
 ///
 /// Consider this project files structure:
+///
 /// ```text
 /// .
 /// ├── Cargo.toml
@@ -1023,7 +1034,9 @@ pub const USER_ROLE: i32 = 0x0100;
 /// └── src
 ///     └── main.rs
 /// ```
+///
 /// then the following Rust code:
+///
 /// ```
 /// use qmetaobject::qrc;
 /// # // For maintainers: this is actually tested against real files.
@@ -1068,7 +1081,9 @@ pub const USER_ROLE: i32 = 0x0100;
 /// use_resource("qrc:/foo2/baz/Foo.qml");
 /// # }
 /// ```
+///
 /// corresponds to the .qrc (`tests/qml/qml.qrc`) file:
+///
 /// ```xml
 /// <RCC>
 ///     <qresource prefix="/foo">
